@@ -1,5 +1,6 @@
 class Platform():
-    def __init__(self, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance, editions=[]):
+    def __init__(self, id, name, is_brand_missing_from_name, platform_family_id, platform_family_name, model_no, storage_capacity, description, disambiguation, relevance, editions=[]):
+        self.id = id
         self.name = name
         self.is_brand_missing_from_name = is_brand_missing_from_name
         self.platform_family_id = platform_family_id
